==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translation type="obsolete">シングル</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translation type="obsolete">２:垂直</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translation type="obsolete">２:水平</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translation>３:右</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translation>３:左</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translation>３:上</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translation type="obsolete">３:下</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translation type="obsolete">３:垂直</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translation type="obsolete">２:垂直</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translation type="obsolete">４:イコール</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translation type="obsolete">４:右</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translation type="obsolete">４:左</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation type="obsolete">グリッド間隔＜メタグリッド間隔</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation type="unfinished">４:イコール</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation type="unfinished">４:左</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation type="unfinished">４:右</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation type="unfinished">シングル</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation type="unfinished">３:下</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation type="unfinished">２:垂直</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation type="unfinished">３:垂直</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation type="unfinished">２:水平</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation type="unfinished">２:垂直</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+320"/>
        <source>Grid</source>
        <translation>グリッド</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>終端</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>エンティティ</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>垂線</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>中心</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>中央</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>交点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>基準点</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation type="unfinished">グリッド間隔＜メタグリッド間隔</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation type="unfinished">グリッド間隔＜メタグリッド間隔</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translation type="obsolete">シングル</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translation type="obsolete">２:垂直</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translation type="obsolete">２:水平</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translation>３:右</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translation>３:左</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translation>３:上</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translation type="obsolete">３:下</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translation type="obsolete">３:垂直</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translation type="obsolete">２:垂直</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translation type="obsolete">４:イコール</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translation type="obsolete">４:右</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translation type="obsolete">４:左</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation type="obsolete">グリッド間隔＜メタグリッド間隔</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>４:イコール</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>４:左</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>４:右</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>単一</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>３:下</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>３:水平</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>３:垂直</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>２:水平</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>２:垂直</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+252"/>
        <source>Dropped data not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Importing file: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Importing URL: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="vanished">グリッド</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="vanished">終端</translation>
    </message>
    <message>
        <source>On Entity</source>
        <translation type="vanished">エンティティ</translation>
    </message>
    <message>
        <source>Perpendicular</source>
        <translation type="vanished">垂線</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">中心</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="vanished">中央</translation>
    </message>
    <message>
        <source>Intersection</source>
        <translation type="vanished">交点</translation>
    </message>
    <message>
        <source>Reference</source>
        <translation type="vanished">基準点</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>グリッド間隔＜メタグリッド間隔</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>グリッド間隔＜メタグリッド間隔</translation>
    </message>
</context>
</TS>
